;;; gnus-load.el --- automatically extracted custom dependencies and autoload
;;
;;; Code:

(autoload 'custom-add-loads "cus-load")

(put 'mime-display 'custom-loads '("mm-decode"))
(put 'spam-stat 'custom-loads '("spam-stat"))
(put 'bbdb-mua-specific-gnus 'custom-loads '("gnus-bbdb"))
(put 'nnmail 'custom-loads '("nnmail"))
(put 'gnus-fun 'custom-loads '("gnus-fun"))
(put 'gnus-article-emphasis 'custom-loads '("gnus-art"))
(put 'gnus-article-headers 'custom-loads '("gnus-art" "gnus-fun" "gnus-sum"))
(put 'gnus-newsrc 'custom-loads '("gnus-start"))
(put 'nnmail-procmail 'custom-loads '("nnmail"))
(put 'gnus-score-kill 'custom-loads '("gnus-kill" "gnus"))
(put 'gnus-visual 'custom-loads '("earcon" "gnus-art" "gnus-audio" "gnus" "smiley"))
(put 'dig 'custom-loads '("dig"))
(put 'gnus-score-expire 'custom-loads '("gnus-kill" "gnus-score"))
(put 'gnus-exit 'custom-loads '("gnus-group" "gnus"))
(put 'nndiary 'custom-loads '("nndiary"))
(put 'gnus-summary-maneuvering 'custom-loads '("gnus-sum"))
(put 'gnus-start 'custom-loads '("gnus-group" "gnus-int" "gnus-start" "gnus-util" "gnus" "nnheader"))
(put 'gnus-extract-view 'custom-loads '("gnus-sum" "gnus-uu"))
(put 'gnus-undo 'custom-loads '("gnus-undo"))
(put 'gnus-various 'custom-loads '("gnus-sum" "gnus-util" "gnus"))
(put 'gnus-meta 'custom-loads '("gnus"))
(put 'mail-source 'custom-loads '("mail-source" "nndiary"))
(put 'gnus-article-washing 'custom-loads '("gnus-art"))
(put 'gnus-score-files 'custom-loads '("gnus-score" "gnus"))
(put 'gnus-agent 'custom-loads '("gnus-agent" "gnus-draft" "gnus"))
(put 'message-news 'custom-loads '("message"))
(put 'smime 'custom-loads '("smime"))
(put 'gnus-xmas 'custom-loads '("gnus-xmas"))
(put 'namazu 'custom-loads '("gnus-namazu"))
(put 'gnus-summary-pick 'custom-loads '("gnus-salt"))
(put 'gnus-thread 'custom-loads '("gnus-sum"))
(put 'languages 'custom-loads '("sieve"))
(put 'spam 'custom-loads '("spam"))
(put 'nnmail-various 'custom-loads '("nnmail"))
(put 'message-various 'custom-loads '("message"))
(put 'gnus-summary-exit 'custom-loads '("gnus-sum" "gnus"))
(put 'news 'custom-loads '("gnus-offline" "gnus" "message" "mm-decode"))
(put 'gnus 'custom-loads '("gnus-art" "gnus-async" "gnus-delay" "gnus-demon" "gnus-dup" "gnus-eform" "gnus-namazu" "gnus-offline" "gnus-sieve" "gnus-undo" "gnus-uu" "gnus-win" "gnus-xmas" "gnus" "mail-source" "mm-url" "nnimap" "nnmail" "nnshimbun" "spam-stat"))
(put 'spam-bogofilter 'custom-loads '("spam"))
(put 'gnus-server 'custom-loads '("gnus-srvr" "gnus" "nnheader"))
(put 'multimedia 'custom-loads '("gnus-audio" "mm-decode"))
(put 'gnus-summary-visual 'custom-loads '("gnus-sum" "gnus"))
(put 'gnus-group-listing 'custom-loads '("gnus-group"))
(put 'gnus-score 'custom-loads '("gnus-nocem" "gnus"))
(put 'gnus-group-select 'custom-loads '("gnus-sum" "gnus"))
(put 'message-buffers 'custom-loads '("message"))
(put 'gnus-threading 'custom-loads '("gnus-sum"))
(put 'gnus-score-decay 'custom-loads '("gnus-score"))
(put 'gnus-score-various 'custom-loads '("gnus-score" "gnus"))
(put 'gnus-nocem 'custom-loads '("gnus-nocem"))
(put 'gnus-group-visual 'custom-loads '("gnus-group" "gnus"))
(put 'gnus-cite 'custom-loads '("gnus-cite"))
(put 'gnus-demon 'custom-loads '("gnus-demon"))
(put 'gnus-message 'custom-loads '("gnus-msg" "message" "gnus"))
(put 'starttls 'custom-loads '("starttls"))
(put 'gnus-summary-tree 'custom-loads '("gnus-salt"))
(put 'gnus-score-default 'custom-loads '("gnus-score" "gnus-sum"))
(put 'nnmail-duplicate 'custom-loads '("nnmail"))
(put 'gnus-format 'custom-loads '("gnus-spec"))
(put 'mime 'custom-loads '("gnus-mailcap" "mm-bodies" "mm-encode" "mm-util" "rfc1843"))
(put 'gnus-delay 'custom-loads '("gnus-delay"))
(put 'message-interface 'custom-loads '("message"))
(put 'nnmail-files 'custom-loads '("nnmail"))
(put 'gnus-edit-form 'custom-loads '("gnus-eform"))
(put 'gnus-audio 'custom-loads '("gnus-audio"))
(put 'gnus-diary 'custom-loads '("gnus-diary" "nndiary"))
(put 'gnus-summary-mail 'custom-loads '("gnus-sum"))
(put 'tools 'custom-loads '("sieve"))
(put 'gnus-topic 'custom-loads '("gnus-topic"))
(put 'gnus-summary-choose 'custom-loads '("gnus-sum"))
(put 'message-headers 'custom-loads '("message"))
(put 'bbdb-mua-specific-gnus-scoring 'custom-loads '("gnus-bbdb"))
(put 'message-forwarding 'custom-loads '("message"))
(put 'message-faces 'custom-loads '("message"))
(put 'gnus-article-treat 'custom-loads '("gnus-art"))
(put 'gnus-charset 'custom-loads '("gnus-group" "gnus-sum" "gnus"))
(put 'gnus-article-mime 'custom-loads '("gnus-art" "gnus-sum" "mm-uu"))
(put 'nnmail-retrieve 'custom-loads '("nnmail"))
(put 'gnus-duplicate 'custom-loads '("gnus-dup"))
(put 'mime-security 'custom-loads '("gnus-art" "mm-decode"))
(put 'earcon 'custom-loads '("earcon"))
(put 'sieve 'custom-loads '("sieve-mode" "sieve"))
(put 'gnus-sieve 'custom-loads '("gnus-sieve"))
(put 'gnus-group-levels 'custom-loads '("gnus-group" "gnus-start" "gnus"))
(put 'mm-url 'custom-loads '("mm-url"))
(put 'gnus-summary-format 'custom-loads '("gnus-diary" "gnus-sum" "gnus"))
(put 'gnus-files 'custom-loads '("gnus" "nnmail"))
(put 'gnus-windows 'custom-loads '("gnus-win"))
(put 'gnus-article-buttons 'custom-loads '("gnus-art"))
(put 'gnus-summary 'custom-loads '("gnus-sum" "gnus"))
(put 'gnus-article-hiding 'custom-loads '("gnus-art" "gnus-sum"))
(put 'gnus-group 'custom-loads '("gnus-topic" "gnus"))
(put 'gnus-article-various 'custom-loads '("gnus-art" "gnus-sum"))
(put 'imap 'custom-loads '("imap"))
(put 'gnus-summary-marks 'custom-loads '("gnus-sum" "gnus"))
(put 'nnmail-expire 'custom-loads '("nnmail"))
(put 'gnus-article-saving 'custom-loads '("gnus-art"))
(put 'message-mail 'custom-loads '("message"))
(put 'faces 'custom-loads '("gnus" "message"))
(put 'gnus-summary-various 'custom-loads '("gnus-sum"))
(put 'applications 'custom-loads '("canlock"))
(put 'gnus-start-server 'custom-loads '("gnus-start"))
(put 'canlock 'custom-loads '("canlock-om" "canlock"))
(put 'gnus-extract-archive 'custom-loads '("gnus-uu"))
(put 'message 'custom-loads '("message" "mml"))
(put 'message-sending 'custom-loads '("message"))
(put 'gnus-group-icons 'custom-loads '("gnus-group"))
(put 'gnus-score-adapt 'custom-loads '("gnus-score" "gnus"))
(put 'message-insertion 'custom-loads '("message"))
(put 'gnus-extract-post 'custom-loads '("gnus-uu"))
(put 'mail 'custom-loads '("gnus-offline" "gnus" "imap" "message" "mm-decode" "sieve-manage" "starttls"))
(put 'gnus-summary-sort 'custom-loads '("gnus-sum"))
(put 'gnus-group-new 'custom-loads '("gnus-start"))
(put 'nnmail-split 'custom-loads '("nndiary" "nnmail"))
(put 'gnus-server-visual 'custom-loads '("gnus-srvr"))
(put 'gnus-asynchronous 'custom-loads '("gnus-async"))
(put 'gnus-dribble-file 'custom-loads '("gnus-start"))
(put 'nnshimbun 'custom-loads '("nnshimbun"))
(put 'gnus-article-highlight 'custom-loads '("gnus-art"))
(put 'gnus-cache 'custom-loads '("gnus-cache" "gnus"))
(put 'gnus-picon 'custom-loads '("gnus-art" "gnus-picon"))
(put 'gnus-extract 'custom-loads '("binhex" "gnus" "gnus-uu" "uudecode"))
(put 'gnus-outlook-deuglify 'custom-loads '("deuglify"))
(put 'gnus-article 'custom-loads '("gnus-art" "gnus-cite" "gnus-sum"))
(put 'nnimap 'custom-loads '("nnimap"))
(put 'nnir 'custom-loads '("nnir"))
(put 'gnus-group-foreign 'custom-loads '("gnus-group" "gnus-msg"))
(put 'gnus-offline 'custom-loads '("gnus-offline"))
(put 'mailcap 'custom-loads '("gnus-mailcap"))
(put 'nnmail-prepare 'custom-loads '("nnmail"))
(put 'gnus-article-signature 'custom-loads '("gnus-art"))
(put 'gnus-namazu 'custom-loads '("gnus-namazu"))
(put 'message-frames 'custom-loads '("message"))
(put 'gnus-group-various 'custom-loads '("gnus-group" "gnus-start" "gnus"))
;;; These are for handling :version.  We need to have a minimum of
;;; information so `custom-changed-variables' could do its job.  
;;; For both groups and variables we have to set `custom-version'.
;;; For variables we also set the `standard-value' and for groups
;;; `group-documentation' (which is shown in the customize buffer), so
;;; we don't have to load the file containing the group.

;;; `custom-versions-load-alist' is an alist that has as car a version
;;; number and as elts the files that have variables that contain that
;;; version. These files should be loaded before showing the
;;; customization buffer that `customize-changed-options' generates.


;;; This macro is used so we don't modify the information about
;;; variables and groups if it's already set. (We don't know when
;;; cus-load.el is going to be loaded and at that time some of the
;;; files might be loaded and some others might not).
(defmacro custom-put-if-not (symbol propname value)
  `(unless (get ,symbol ,propname)
     (put ,symbol ,propname ,value)))

(custom-put-if-not 'mime-display 'custom-version "21.1")
(custom-put-if-not 'mime-display 'group-documentation "Display of MIME in mail and news articles.")
(custom-put-if-not 'gnus-agent-synchronize-flags 'custom-version "21.1")
(custom-put-if-not 'gnus-agent-synchronize-flags 'standard-value t)
(custom-put-if-not 'message-dont-reply-to-names 'custom-version "21.1")
(custom-put-if-not 'message-dont-reply-to-names 'standard-value t)
(custom-put-if-not 'nnmail-expiry-target 'custom-version "21.1")
(custom-put-if-not 'nnmail-expiry-target 'standard-value t)
(custom-put-if-not 'mail-source 'custom-version "21.1")
(custom-put-if-not 'mail-source 'group-documentation "The mail-fetching library.")
(custom-put-if-not 'message-insert-canlock 'custom-version "21.3")
(custom-put-if-not 'message-insert-canlock 'standard-value t)
(custom-put-if-not 'gnus-agent 'custom-version "21.3")
(custom-put-if-not 'gnus-agent 'standard-value t)
(custom-put-if-not 'gnus-unbuttonized-mime-types 'custom-version "21.1")
(custom-put-if-not 'gnus-unbuttonized-mime-types 'standard-value t)
(custom-put-if-not 'gnus-buttonized-mime-types 'custom-version "21.1")
(custom-put-if-not 'gnus-buttonized-mime-types 'standard-value t)
(custom-put-if-not 'gnus-agent-cache 'custom-version "21.3")
(custom-put-if-not 'gnus-agent-cache 'standard-value t)
(custom-put-if-not 'gnus-article-loose-mime 'custom-version "21.3")
(custom-put-if-not 'gnus-article-loose-mime 'standard-value t)
(custom-put-if-not 'gnus-debug-files 'custom-version "21.1")
(custom-put-if-not 'gnus-debug-files 'standard-value t)
(custom-put-if-not 'message-wide-reply-confirm-recipients 'custom-version "21.3")
(custom-put-if-not 'message-wide-reply-confirm-recipients 'standard-value t)
(custom-put-if-not 'gnus-article-banner-alist 'custom-version "21.1")
(custom-put-if-not 'gnus-article-banner-alist 'standard-value t)
(custom-put-if-not 'gnus-agent-download-marks 'custom-version "21.1")
(custom-put-if-not 'gnus-agent-download-marks 'standard-value t)
(custom-put-if-not 'gnus-gcc-mark-as-read 'custom-version "21.1")
(custom-put-if-not 'gnus-gcc-mark-as-read 'standard-value t)
(custom-put-if-not 'mm-text-html-renderer 'custom-version "21.3")
(custom-put-if-not 'mm-text-html-renderer 'standard-value t)
(custom-put-if-not 'gnus-agent-go-online 'custom-version "21.1")
(custom-put-if-not 'gnus-agent-go-online 'standard-value t)
(custom-put-if-not 'gnus-use-byte-compile 'custom-version "21.1")
(custom-put-if-not 'gnus-use-byte-compile 'standard-value t)
(custom-put-if-not 'gnus-ignored-from-addresses 'custom-version "21.1")
(custom-put-if-not 'gnus-ignored-from-addresses 'standard-value t)
(custom-put-if-not 'gnus-inhibit-mime-unbuttonizing 'custom-version "21.3")
(custom-put-if-not 'gnus-inhibit-mime-unbuttonizing 'standard-value t)
(custom-put-if-not 'gnus-group-name-charset-method-alist 'custom-version "21.1")
(custom-put-if-not 'gnus-group-name-charset-method-alist 'standard-value t)
(custom-put-if-not 'starttls 'custom-version "21.1")
(custom-put-if-not 'starttls 'group-documentation "Support for `Transport Layer Security' protocol.")
(custom-put-if-not 'gnus-article-date-lapsed-new-header 'custom-version "21.1")
(custom-put-if-not 'gnus-article-date-lapsed-new-header 'standard-value t)
(custom-put-if-not 'gnus-extra-headers 'custom-version "21.1")
(custom-put-if-not 'gnus-extra-headers 'standard-value t)
(custom-put-if-not 'gnus-agent-mark-unread-after-downloaded 'custom-version "21.1")
(custom-put-if-not 'gnus-agent-mark-unread-after-downloaded 'standard-value t)
(custom-put-if-not 'gnus-summary-muttprint-program 'custom-version "21.3")
(custom-put-if-not 'gnus-summary-muttprint-program 'standard-value t)
(custom-put-if-not 'gnus-auto-expirable-marks 'custom-version "21.1")
(custom-put-if-not 'gnus-auto-expirable-marks 'standard-value t)
(custom-put-if-not 'gnus-article-mime-match-handle-function 'custom-version "21.1")
(custom-put-if-not 'gnus-article-mime-match-handle-function 'standard-value t)
(custom-put-if-not 'gnus-discouraged-post-methods 'custom-version "21.3")
(custom-put-if-not 'gnus-discouraged-post-methods 'standard-value t)
(custom-put-if-not 'gnus-audio 'custom-version "21.1")
(custom-put-if-not 'gnus-audio 'group-documentation "Playing sound in Gnus.")
(custom-put-if-not 'message-mail-user-agent 'custom-version "21.1")
(custom-put-if-not 'message-mail-user-agent 'standard-value t)
(custom-put-if-not 'gnus-nocem-check-article-limit 'custom-version "21.1")
(custom-put-if-not 'gnus-nocem-check-article-limit 'standard-value t)
(custom-put-if-not 'nnmail-extra-headers 'custom-version "21.1")
(custom-put-if-not 'nnmail-extra-headers 'standard-value t)
(custom-put-if-not 'gnus-mime-multipart-functions 'custom-version "21.1")
(custom-put-if-not 'gnus-mime-multipart-functions 'standard-value t)
(custom-put-if-not 'gnus-treat-display-grey-xface 'custom-version "21.3")
(custom-put-if-not 'gnus-treat-display-grey-xface 'standard-value t)
(custom-put-if-not 'gnus-charset 'custom-version "21.1")
(custom-put-if-not 'gnus-charset 'group-documentation "Group character set issues.")
(custom-put-if-not 'gnus-nocem-check-from 'custom-version "21.1")
(custom-put-if-not 'gnus-nocem-check-from 'standard-value t)
(custom-put-if-not 'message-forward-as-mime 'custom-version "21.1")
(custom-put-if-not 'message-forward-as-mime 'standard-value t)
(custom-put-if-not 'gnus-summary-display-arrow 'custom-version "21.1")
(custom-put-if-not 'gnus-summary-display-arrow 'standard-value t)
(custom-put-if-not 'gnus-debug-exclude-variables 'custom-version "21.1")
(custom-put-if-not 'gnus-debug-exclude-variables 'standard-value t)
(custom-put-if-not 'gnus-list-identifiers 'custom-version "21.1")
(custom-put-if-not 'gnus-list-identifiers 'standard-value t)
(custom-put-if-not 'imap 'custom-version "21.1")
(custom-put-if-not 'imap 'group-documentation "Low-level IMAP issues.")
(custom-put-if-not 'message-forward-ignored-headers 'custom-version "21.1")
(custom-put-if-not 'message-forward-ignored-headers 'standard-value t)
(custom-put-if-not 'gnus-agent-consider-all-articles 'custom-version "21.4")
(custom-put-if-not 'gnus-agent-consider-all-articles 'standard-value t)
(custom-put-if-not 'nnmail-scan-directory-mail-source-once 'custom-version "21.1")
(custom-put-if-not 'nnmail-scan-directory-mail-source-once 'standard-value t)
(custom-put-if-not 'gnus-preserve-marks 'custom-version "21.1")
(custom-put-if-not 'gnus-preserve-marks 'standard-value t)
(custom-put-if-not 'gnus-gcc-externalize-attachments 'custom-version "21.1")
(custom-put-if-not 'gnus-gcc-externalize-attachments 'standard-value t)
(custom-put-if-not 'gnus-inhibit-user-auto-expire 'custom-version "21.1")
(custom-put-if-not 'gnus-inhibit-user-auto-expire 'standard-value t)
(custom-put-if-not 'gnus-emphasize-whitespace-regexp 'custom-version "21.1")
(custom-put-if-not 'gnus-emphasize-whitespace-regexp 'standard-value t)
(custom-put-if-not 'gnus-summary-show-article-charset-alist 'custom-version "21.1")
(custom-put-if-not 'gnus-summary-show-article-charset-alist 'standard-value t)
(custom-put-if-not 'gnus-read-newsrc-file 'custom-version "21.1")
(custom-put-if-not 'gnus-read-newsrc-file 'standard-value t)
(custom-put-if-not 'nnmail-split-header-length-limit 'custom-version "21.1")
(custom-put-if-not 'nnmail-split-header-length-limit 'standard-value t)
(custom-put-if-not 'gnus-ignored-mime-types 'custom-version "21.1")
(custom-put-if-not 'gnus-ignored-mime-types 'standard-value t)
(custom-put-if-not 'gnus-agent-confirmation-function 'custom-version "21.1")
(custom-put-if-not 'gnus-agent-confirmation-function 'standard-value t)
(custom-put-if-not 'gnus-group-highlight-words-alist 'custom-version "21.1")
(custom-put-if-not 'gnus-group-highlight-words-alist 'standard-value t)
(custom-put-if-not 'gnus-newsgroup-ignored-charsets 'custom-version "21.1")
(custom-put-if-not 'gnus-newsgroup-ignored-charsets 'standard-value t)
(custom-put-if-not 'message-send-mail-partially-limit 'custom-version "21.1")
(custom-put-if-not 'message-send-mail-partially-limit 'standard-value t)
(custom-put-if-not 'message-forward-show-mml 'custom-version "21.1")
(custom-put-if-not 'message-forward-show-mml 'standard-value t)
(custom-put-if-not 'message-default-charset 'custom-version "21.1")
(custom-put-if-not 'message-default-charset 'standard-value t)
(custom-put-if-not 'mailcap 'custom-version "21.1")
(custom-put-if-not 'mailcap 'group-documentation "Definition of viewers for MIME types.")


;;;### (autoloads (binhex-decode-region binhex-decode-region-external
;;;;;;  binhex-decode-region-internal) "binhex" "binhex.el" (15895
;;;;;;  52374))
;;; Generated autoloads from binhex.el

(defconst binhex-begin-line "^:...............................................................$")

(autoload (quote binhex-decode-region-internal) "binhex" "\
Binhex decode region between START and END without using an external program.
If HEADER-ONLY is non-nil only decode header and return filename." t nil)

(autoload (quote binhex-decode-region-external) "binhex" "\
Binhex decode region between START and END using external decoder." t nil)

(autoload (quote binhex-decode-region) "binhex" "\
Binhex decode region between START and END." t nil)

;;;***

;;;### (autoloads (canlock-verify canlock-insert-header) "canlock"
;;;;;;  "canlock.el" (15575 16891))
;;; Generated autoloads from canlock.el

(autoload (quote canlock-insert-header) "canlock" "\
Insert a Cancel-Key and/or a Cancel-Lock header if possible." nil nil)

(autoload (quote canlock-verify) "canlock" "\
Verify Cancel-Lock or Cancel-Key in BUFFER.
If BUFFER is nil, the current buffer is assumed.  Signal an error if
it fails.  You can modify the behavior of this function to return non-
nil instead of to signal an error by setting the option
`canlock-ignore-errors' to non-nil." t nil)

;;;***

;;;### (autoloads (gnus-article-outlook-deuglify-article gnus-outlook-deuglify-article
;;;;;;  gnus-outlook-repair-attribution gnus-outlook-unwrap-lines
;;;;;;  gnus-outlook-deuglify-unwrap-max gnus-outlook-deuglify-unwrap-min)
;;;;;;  "deuglify" "deuglify.el" (15895 52374))
;;; Generated autoloads from deuglify.el

(defvar gnus-outlook-deuglify-unwrap-min 45 "\
Minimum length of the cited line above the (possibly) wrapped line.")

(defvar gnus-outlook-deuglify-unwrap-max 95 "\
Maximum length of the cited line after unwrapping.")

(autoload (quote gnus-outlook-unwrap-lines) "deuglify" "\
Unwrap lines that appear to be wrapped citation lines.
You can control what lines will be unwrapped by frobbing
`gnus-outlook-deuglify-unwrap-min' and
`gnus-outlook-deuglify-unwrap-max', indicating the miminum and maximum
length of an unwrapped citation line." t nil)

(autoload (quote gnus-outlook-repair-attribution) "deuglify" "\
Repair a broken attribution line." t nil)

(autoload (quote gnus-outlook-deuglify-article) "deuglify" "\
Deuglify broken Outlook (Express) articles." t nil)

(autoload (quote gnus-article-outlook-deuglify-article) "deuglify" "\
Deuglify broken Outlook (Express) articles and redisplay." t nil)

;;;***

;;;### (autoloads (gnus-earcon-display) "earcon" "earcon.el" (15418
;;;;;;  33141))
;;; Generated autoloads from earcon.el

(autoload (quote gnus-earcon-display) "earcon" "\
Play sounds in message buffers." t nil)

;;;***

;;;### (autoloads (gnus gnus-other-frame gnus-slave gnus-no-server
;;;;;;  gnus-slave-no-server) "gnus" "gnus.el" (15895 52379))
;;; Generated autoloads from gnus.el

(autoload (quote gnus-slave-no-server) "gnus" "\
Read network news as a slave, without connecting to the local server." t nil)

(autoload (quote gnus-no-server) "gnus" "\
Read network news.
If ARG is a positive number, Gnus will use that as the startup
level. If ARG is nil, Gnus will be started at level 2.  If ARG is
non-nil and not a positive number, Gnus will prompt the user for the
name of an NNTP server to use.
As opposed to `gnus', this command will not connect to the local
server." t nil)

(autoload (quote gnus-slave) "gnus" "\
Read news as a slave." t nil)

(autoload (quote gnus-other-frame) "gnus" "\
Pop up a frame to read news.
This will call one of the Gnus commands which is specified by the user
option `gnus-other-frame-function' (default `gnus') with the argument
ARG if Gnus is not running, otherwise just pop up a Gnus frame.  The
optional second argument DISPLAY should be a standard display string
such as \"unix:0\" to specify where to pop up a frame.  If DISPLAY is
omitted or the function `make-frame-on-display' is not available, the
current display is used." t nil)

(autoload (quote gnus) "gnus" "\
Read network news.
If ARG is non-nil and a positive number, Gnus will use that as the
startup level.	If ARG is non-nil and not a positive number, Gnus will
prompt the user for the name of an NNTP server to use." t nil)

;;;***

;;;### (autoloads (gnus-agent-regenerate gnus-agent-batch gnus-agent-batch-fetch
;;;;;;  gnus-agent-possibly-save-gcc gnus-agentize gnus-slave-unplugged
;;;;;;  gnus-plugged gnus-unplugged) "gnus-agent" "gnus-agent.el"
;;;;;;  (15895 52374))
;;; Generated autoloads from gnus-agent.el

(autoload (quote gnus-unplugged) "gnus-agent" "\
Start Gnus unplugged." t nil)

(autoload (quote gnus-plugged) "gnus-agent" "\
Start Gnus plugged." t nil)

(autoload (quote gnus-slave-unplugged) "gnus-agent" "\
Read news as a slave unplugged." t nil)

(autoload (quote gnus-agentize) "gnus-agent" "\
Allow Gnus to be an offline newsreader.
The normal usage of this command is to put the following as the
last form in your `.gnus.el' file:

\(gnus-agentize)

This will modify the `gnus-setup-news-hook', and
`message-send-mail-real-function' variables, and install the Gnus agent
minor mode in all Gnus buffers." t nil)

(autoload (quote gnus-agent-possibly-save-gcc) "gnus-agent" "\
Save GCC if Gnus is unplugged." nil nil)

(autoload (quote gnus-agent-batch-fetch) "gnus-agent" "\
Start Gnus and fetch session." t nil)

(autoload (quote gnus-agent-batch) "gnus-agent" "\
Start Gnus, send queue and fetch session." t nil)

(autoload (quote gnus-agent-regenerate) "gnus-agent" "\
Regenerate all agent covered files.
If CLEAN, don't read existing active files." t nil)

;;;***

;;;### (autoloads (gnus-article-prepare-display) "gnus-art" "gnus-art.el"
;;;;;;  (15895 52375))
;;; Generated autoloads from gnus-art.el

(autoload (quote gnus-article-prepare-display) "gnus-art" "\
Make the current buffer look like a nice article." nil nil)

;;;***

;;;### (autoloads (gnus-audio-play) "gnus-audio" "gnus-audio.el"
;;;;;;  (15418 33141))
;;; Generated autoloads from gnus-audio.el

(autoload (quote gnus-audio-play) "gnus-audio" "\
Play a sound FILE through the speaker." t nil)

;;;***

;;;### (autoloads (gnus-bbdb-insinuate-message gnus-bbdb-insinuate
;;;;;;  gnus-bbdb/score gnus-bbdb/lines-and-from gnus-bbdb/split-mail
;;;;;;  gnus-bbdb/show-sender gnus-bbdb/annotate-sender gnus-bbdb/update-record)
;;;;;;  "gnus-bbdb" "gnus-bbdb.el" (15575 16892))
;;; Generated autoloads from gnus-bbdb.el

(autoload (quote gnus-bbdb/update-record) "gnus-bbdb" "\
Return the record corresponding to the current GNUS message, creating
or modifying it as necessary.  A record will be created if
bbdb/news-auto-create-p is non-nil, or if OFFER-TO-CREATE is true and
the user confirms the creation." nil nil)

(autoload (quote gnus-bbdb/annotate-sender) "gnus-bbdb" "\
Add a line to the end of the Notes field of the BBDB record
corresponding to the sender of this message.  If REPLACE is non-nil,
replace the existing notes entry (if any)." t nil)

(autoload (quote gnus-bbdb/show-sender) "gnus-bbdb" "\
Display the contents of the BBDB for the sender of this message.
This buffer will be in bbdb-mode, with associated keybindings." t nil)

(autoload (quote gnus-bbdb/split-mail) "gnus-bbdb" "\
Mail split method for `nnmail-split-fancy'.
HEADER-FIELD is a regexp or list of regexps as mail header field name
for gathering mail addresses.  If HEADER-FIELD is a string, then it's
used for just matching pattern.  If HEADER-FIELD is a list of strings,
then these strings have priorities in the order.

BBDB-FIELD is field name of BBDB.
Optional argument REGEXP is regexp string for matching BBDB-FIELD value.
If REGEXP is nil or not specified, then all BBDB-FIELD value is matched.

If GROUP is nil or not specified, then BBDB-FIELD value is returned as
group name.  If GROUP is a symbol `&', then list of all matching group's
BBDB-FIELD values is returned.  Otherwise, GROUP is returned." nil nil)

(autoload (quote gnus-bbdb/lines-and-from) "gnus-bbdb" "\
Useful as the value of gnus-optional-headers in *GNUS* (not Gnus).
NOTE: This variable no longer seems to be present in Gnus.  It seems
to have been replaced by `message-default-headers', which only takes
strings.  In the future this should change." nil nil)

(autoload (quote gnus-bbdb/score) "gnus-bbdb" "\
This returns a score alist for GNUS.  A score pair will be made for
every member of the net field in records which also have a gnus-score
field.  This allows the BBDB to serve as a supplemental global score
file, with the advantage that it can keep up with multiple and changing
addresses better than the traditionally static global scorefile." nil nil)

(autoload (quote gnus-bbdb-insinuate) "gnus-bbdb" "\
Call this function to hook BBDB into Semi-gnus." nil nil)

(autoload (quote gnus-bbdb-insinuate-message) "gnus-bbdb" "\
Call this function to hook BBDB into message-mode." nil nil)

;;;***

;;;### (autoloads (gnus-cache-generate-nov-databases gnus-cache-generate-active
;;;;;;  gnus-jog-cache) "gnus-cache" "gnus-cache.el" (15895 52375))
;;; Generated autoloads from gnus-cache.el

(autoload (quote gnus-jog-cache) "gnus-cache" "\
Go through all groups and put the articles into the cache.

Usage:
$ emacs -batch -l ~/.emacs -l gnus -f gnus-jog-cache" t nil)

(autoload (quote gnus-cache-generate-active) "gnus-cache" "\
Generate the cache active file." t nil)

(autoload (quote gnus-cache-generate-nov-databases) "gnus-cache" "\
Generate NOV files recursively starting in DIR." t nil)

;;;***

;;;### (autoloads (find-cl-run-time-functions) "gnus-clfns" "gnus-clfns.el"
;;;;;;  (15439 59183))
;;; Generated autoloads from gnus-clfns.el

(autoload (quote find-cl-run-time-functions) "gnus-clfns" "\
Find CL run-time functions in the FILE-OR-DIRECTORY.  You can alter
the behavior of this command with the prefix ARG as described below.

By default, it searches for all the CL run-time functions listed in
 the variable `cl-run-time-functions'.
With 1 or 3 \\[universal-argument]'s, the built-in functions in this Emacs will not be
 reported.
With 2 or 3 \\[universal-argument]'s, just the symbols will also be reported.

You can use the `digit-argument' 1, 2 or 3 instead of \\[universal-argument]'s." t nil)

;;;***

;;;### (autoloads (gnus-delay-initialize gnus-delay-send-queue gnus-delay-article)
;;;;;;  "gnus-delay" "gnus-delay.el" (15695 54011))
;;; Generated autoloads from gnus-delay.el

(defgroup gnus-delay nil "Arrange for sending postings later." :group (quote gnus))

(autoload (quote gnus-delay-article) "gnus-delay" "\
Delay this article by some time.
DELAY is a string, giving the length of the time.  Possible values are:

* <digits><units> for <units> in minutes (`m'), hours (`h'), days (`d'),
  weeks (`w'), months (`M'), or years (`Y');

* YYYY-MM-DD for a specific date.  The time of day is given by the
  variable `gnus-delay-default-hour', minute and second are zero.

* hh:mm for a specific time.  Use 24h format.  If it is later than this
  time, then the deadline is tomorrow, else today." t nil)

(autoload (quote gnus-delay-send-queue) "gnus-delay" "\
Send all the delayed messages that are due now." t nil)

(autoload (quote gnus-delay-initialize) "gnus-delay" "\
Initialize the gnus-delay package.
This sets up a key binding in `message-mode' to delay a message.
This tells Gnus to look for delayed messages after getting new news.

The optional arg NO-KEYMAP is ignored.
Checking delayed messages is skipped if optional arg NO-CHECK is non-nil." nil nil)

;;;***

;;;### (autoloads (turn-on-gnus-dired-mode) "gnus-dired" "gnus-dired.el"
;;;;;;  (15575 16892))
;;; Generated autoloads from gnus-dired.el

(autoload (quote turn-on-gnus-dired-mode) "gnus-dired" "\
Convenience method to turn on gnus-dired-mode." nil nil)

;;;***

;;;### (autoloads (gnus-draft-reminder) "gnus-draft" "gnus-draft.el"
;;;;;;  (15895 52375))
;;; Generated autoloads from gnus-draft.el

(autoload (quote gnus-draft-reminder) "gnus-draft" "\
Reminder user if there are unsent drafts." t nil)

;;;***

;;;### (autoloads (gnus-convert-gray-x-face-region gnus-convert-gray-x-face-to-xpm
;;;;;;  gnus-x-face-from-file gnus-random-x-face) "gnus-fun" "gnus-fun.el"
;;;;;;  (15695 54011))
;;; Generated autoloads from gnus-fun.el

(autoload (quote gnus-random-x-face) "gnus-fun" "\
Insert a random X-Face header from `gnus-x-face-directory'." t nil)

(autoload (quote gnus-x-face-from-file) "gnus-fun" "\
Insert an X-Face header based on an image file." t nil)

(autoload (quote gnus-convert-gray-x-face-to-xpm) "gnus-fun" nil nil nil)

(autoload (quote gnus-convert-gray-x-face-region) "gnus-fun" "\
Convert the X-Faces in region to a PPM file." t nil)

;;;***

;;;### (autoloads (gnus-fetch-group-other-frame gnus-fetch-group)
;;;;;;  "gnus-group" "gnus-group.el" (15895 52376))
;;; Generated autoloads from gnus-group.el

(autoload (quote gnus-fetch-group) "gnus-group" "\
Start Gnus if necessary and enter GROUP.
Returns whether the fetching was successful or not." t nil)

(autoload (quote gnus-fetch-group-other-frame) "gnus-group" "\
Pop up a frame and enter GROUP." t nil)

;;;***

;;;### (autoloads (gnus-batch-score) "gnus-kill" "gnus-kill.el" (15575
;;;;;;  16892))
;;; Generated autoloads from gnus-kill.el

(defalias (quote gnus-batch-kill) (quote gnus-batch-score))

(autoload (quote gnus-batch-score) "gnus-kill" "\
Run batched scoring.
Usage: emacs -batch -l ~/.emacs -l gnus -f gnus-batch-score" t nil)

;;;***

;;;### (autoloads (gnus-mailing-list-mode gnus-mailing-list-insinuate
;;;;;;  turn-on-gnus-mailing-list-mode) "gnus-ml" "gnus-ml.el" (15418
;;;;;;  33142))
;;; Generated autoloads from gnus-ml.el

(autoload (quote turn-on-gnus-mailing-list-mode) "gnus-ml" nil nil nil)

(autoload (quote gnus-mailing-list-insinuate) "gnus-ml" "\
Setup group parameters from List-Post header.
If FORCE is non-nil, replace the old ones." t nil)

(autoload (quote gnus-mailing-list-mode) "gnus-ml" "\
Minor mode for providing mailing-list commands.

\\{gnus-mailing-list-mode-map}" t nil)

;;;***

;;;### (autoloads (gnus-group-split-fancy gnus-group-split gnus-group-split-update
;;;;;;  gnus-group-split-setup) "gnus-mlspl" "gnus-mlspl.el" (15895
;;;;;;  52376))
;;; Generated autoloads from gnus-mlspl.el

(autoload (quote gnus-group-split-setup) "gnus-mlspl" "\
Set up the split for nnmail-split-fancy.
Sets things up so that nnmail-split-fancy is used for mail
splitting, and defines the variable nnmail-split-fancy according with
group parameters.

If AUTO-UPDATE is non-nil (prefix argument accepted, if called
interactively), it makes sure nnmail-split-fancy is re-computed before
getting new mail, by adding gnus-group-split-update to
nnmail-pre-get-new-mail-hook.

A non-nil CATCH-ALL replaces the current value of
gnus-group-split-default-catch-all-group.  This variable is only used
by gnus-group-split-update, and only when its CATCH-ALL argument is
nil.  This argument may contain any fancy split, that will be added as
the last split in a `|' split produced by gnus-group-split-fancy,
unless overridden by any group marked as a catch-all group.  Typical
uses are as simple as the name of a default mail group, but more
elaborate fancy splits may also be useful to split mail that doesn't
match any of the group-specified splitting rules.  See
`gnus-group-split-fancy' for details." t nil)

(autoload (quote gnus-group-split-update) "gnus-mlspl" "\
Computes nnmail-split-fancy from group params and CATCH-ALL, by
calling (gnus-group-split-fancy nil nil CATCH-ALL).

If CATCH-ALL is nil, gnus-group-split-default-catch-all-group is used
instead.  This variable is set by gnus-group-split-setup." t nil)

(autoload (quote gnus-group-split) "gnus-mlspl" "\
Uses information from group parameters in order to split mail.
See `gnus-group-split-fancy' for more information.

gnus-group-split is a valid value for nnmail-split-methods." nil nil)

(autoload (quote gnus-group-split-fancy) "gnus-mlspl" "\
Uses information from group parameters in order to split mail.
It can be embedded into `nnmail-split-fancy' lists with the SPLIT

\(: gnus-group-split-fancy GROUPS NO-CROSSPOST CATCH-ALL)

GROUPS may be a regular expression or a list of group names, that will
be used to select candidate groups.  If it is omitted or nil, all
existing groups are considered.

if NO-CROSSPOST is omitted or nil, a & split will be returned,
otherwise, a | split, that does not allow crossposting, will be
returned.

For each selected group, a SPLIT is composed like this: if SPLIT-SPEC
is specified, this split is returned as-is (unless it is nil: in this
case, the group is ignored).  Otherwise, if TO-ADDRESS, TO-LIST and/or
EXTRA-ALIASES are specified, a regexp that matches any of them is
constructed (extra-aliases may be a list).  Additionally, if
SPLIT-REGEXP is specified, the regexp will be extended so that it
matches this regexp too, and if SPLIT-EXCLUDE is specified, RESTRICT
clauses will be generated.

If CATCH-ALL is nil, no catch-all handling is performed, regardless of
catch-all marks in group parameters.  Otherwise, if there is no
selected group whose SPLIT-REGEXP matches the empty string, nor is
there a selected group whose SPLIT-SPEC is 'catch-all, this fancy
split (say, a group name) will be appended to the returned SPLIT list,
as the last element of a '| SPLIT.

For example, given the following group parameters:

nnml:mail.bar:
\((to-address . \"bar@femail.com\")
 (split-regexp . \".*@femail\\\\.com\"))
nnml:mail.foo:
\((to-list . \"foo@nowhere.gov\")
 (extra-aliases \"foo@localhost\" \"foo-redist@home\")
 (split-exclude \"bugs-foo\" \"rambling-foo\")
 (admin-address . \"foo-request@nowhere.gov\"))
nnml:mail.others:
\((split-spec . catch-all))

Calling (gnus-group-split-fancy nil nil \"mail.others\") returns:

\(| (& (any \"\\\\(bar@femail\\\\.com\\\\|.*@femail\\\\.com\\\\)\"
	   \"mail.bar\")
      (any \"\\\\(foo@nowhere\\\\.gov\\\\|foo@localhost\\\\|foo-redist@home\\\\)\"
	   - \"bugs-foo\" - \"rambling-foo\" \"mail.foo\"))
   \"mail.others\")" nil nil)

;;;***

;;;### (autoloads (gnus-change-server) "gnus-move" "gnus-move.el"
;;;;;;  (15066 10800))
;;; Generated autoloads from gnus-move.el

(autoload (quote gnus-change-server) "gnus-move" "\
Move from FROM-SERVER to TO-SERVER.
Update the .newsrc.eld file to reflect the change of nntp server." t nil)

;;;***

;;;### (autoloads (gnus-button-reply gnus-button-mailto gnus-msg-mail)
;;;;;;  "gnus-msg" "gnus-msg.el" (15895 52376))
;;; Generated autoloads from gnus-msg.el

(autoload (quote gnus-msg-mail) "gnus-msg" "\
Start editing a mail message to be sent.
Like `message-mail', but with Gnus paraphernalia, particularly the
Gcc: header for archiving purposes." t nil)

(autoload (quote gnus-button-mailto) "gnus-msg" "\
Mail to ADDRESS." nil nil)

(autoload (quote gnus-button-reply) "gnus-msg" "\
Like `message-reply'." t nil)

(define-mail-user-agent (quote gnus-user-agent) (quote gnus-msg-mail) (quote message-send-and-exit) (quote message-kill-buffer) (quote message-send-hook))

;;;***

;;;### (autoloads (gnus-namazu-insinuate gnus-namazu-stop-update
;;;;;;  gnus-namazu-update-all-indices gnus-namazu-update-index gnus-namazu-create-index
;;;;;;  gnus-namazu-search) "gnus-namazu" "gnus-namazu.el" (15895
;;;;;;  52376))
;;; Generated autoloads from gnus-namazu.el

(autoload (quote gnus-namazu-search) "gnus-namazu" "\
Search QUERY through GROUPS with Namazu,
and make a virtual group contains its results." t nil)

(autoload (quote gnus-namazu-create-index) "gnus-namazu" "\
Create index under DIRECTORY." t nil)

(autoload (quote gnus-namazu-update-index) "gnus-namazu" "\
Update the index under the DIRECTORY." t nil)

(autoload (quote gnus-namazu-update-all-indices) "gnus-namazu" "\
Update all indices which is set to `gnus-namazu-index-directories'." t nil)

(autoload (quote gnus-namazu-stop-update) "gnus-namazu" "\
Stop the running indexer of Namazu." t nil)

(autoload (quote gnus-namazu-insinuate) "gnus-namazu" nil nil nil)

;;;***

;;;### (autoloads (gnus-treat-newsgroups-picon gnus-treat-mail-picon
;;;;;;  gnus-treat-from-picon) "gnus-picon" "gnus-picon.el" (15435
;;;;;;  43748))
;;; Generated autoloads from gnus-picon.el

(autoload (quote gnus-treat-from-picon) "gnus-picon" "\
Display picons in the From header.
If picons are already displayed, remove them." t nil)

(autoload (quote gnus-treat-mail-picon) "gnus-picon" "\
Display picons in the Cc and To headers.
If picons are already displayed, remove them." t nil)

(autoload (quote gnus-treat-newsgroups-picon) "gnus-picon" "\
Display picons in the Newsgroups and Followup-To headers.
If picons are already displayed, remove them." t nil)

;;;***

;;;### (autoloads (gnus-add-to-sorted-list gnus-sorted-nunion gnus-sorted-union
;;;;;;  gnus-sorted-nintersection gnus-sorted-intersection gnus-intersection
;;;;;;  gnus-sorted-complement gnus-sorted-ndifference gnus-sorted-difference)
;;;;;;  "gnus-range" "gnus-range.el" (15895 52376))
;;; Generated autoloads from gnus-range.el

(autoload (quote gnus-sorted-difference) "gnus-range" "\
Return a list of elements of LIST1 that do not appear in LIST2.
Both lists have to be sorted over <.
The tail of LIST1 is not copied." nil nil)

(autoload (quote gnus-sorted-ndifference) "gnus-range" "\
Return a list of elements of LIST1 that do not appear in LIST2.
Both lists have to be sorted over <.
LIST1 is modified." nil nil)

(autoload (quote gnus-sorted-complement) "gnus-range" "\
Return a list of elements that are in LIST1 or LIST2 but not both.
Both lists have to be sorted over <." nil nil)

(autoload (quote gnus-intersection) "gnus-range" nil nil nil)

(autoload (quote gnus-sorted-intersection) "gnus-range" "\
Return intersection of LIST1 and LIST2.
LIST1 and LIST2 have to be sorted over <." nil nil)

(defalias (quote gnus-set-sorted-intersection) (quote gnus-sorted-nintersection))

(autoload (quote gnus-sorted-nintersection) "gnus-range" "\
Return intersection of LIST1 and LIST2 by modifying cdr pointers of LIST1.
LIST1 and LIST2 have to be sorted over <." nil nil)

(autoload (quote gnus-sorted-union) "gnus-range" "\
Return union of LIST1 and LIST2.
LIST1 and LIST2 have to be sorted over <." nil nil)

(autoload (quote gnus-sorted-nunion) "gnus-range" "\
Return union of LIST1 and LIST2 by modifying cdr pointers of LIST1.
LIST1 and LIST2 have to be sorted over <." nil nil)

(autoload (quote gnus-add-to-sorted-list) "gnus-range" "\
Add NUM into sorted LIST by side effect." nil nil)

;;;***

;;;### (autoloads (gnus-sieve-article-add-rule gnus-sieve-generate
;;;;;;  gnus-sieve-update) "gnus-sieve" "gnus-sieve.el" (15695 54012))
;;; Generated autoloads from gnus-sieve.el

(autoload (quote gnus-sieve-update) "gnus-sieve" "\
Update the Sieve script in gnus-sieve-file, by replacing the region
between gnus-sieve-region-start and gnus-sieve-region-end with
\(gnus-sieve-script gnus-sieve-select-method gnus-sieve-crosspost), then
execute gnus-sieve-update-shell-command.
See the documentation for these variables and functions for details." t nil)

(autoload (quote gnus-sieve-generate) "gnus-sieve" "\
Generate the Sieve script in gnus-sieve-file, by replacing the region
between gnus-sieve-region-start and gnus-sieve-region-end with
\(gnus-sieve-script gnus-sieve-select-method gnus-sieve-crosspost).
See the documentation for these variables and functions for details." t nil)

(autoload (quote gnus-sieve-article-add-rule) "gnus-sieve" nil t nil)

;;;***

;;;### (autoloads (gnus-batch-brew-soup) "gnus-soup" "gnus-soup.el"
;;;;;;  (15895 52376))
;;; Generated autoloads from gnus-soup.el

(autoload (quote gnus-batch-brew-soup) "gnus-soup" "\
Brew a SOUP packet from groups mention on the command line.
Will use the remaining command line arguments as regular expressions
for matching on group names.

For instance, if you want to brew on all the nnml groups, as well as
groups with \"emacs\" in the name, you could say something like:

$ emacs -batch -f gnus-batch-brew-soup ^nnml \".*emacs.*\"

Note -- this function hasn't been implemented yet." t nil)

;;;***

;;;### (autoloads (gnus-update-format) "gnus-spec" "gnus-spec.el"
;;;;;;  (15895 52376))
;;; Generated autoloads from gnus-spec.el

(autoload (quote gnus-update-format) "gnus-spec" "\
Update the format specification near point." t nil)

;;;***

;;;### (autoloads (gnus-fixup-nnimap-unread-after-getting-new-news
;;;;;;  gnus-declare-backend gnus-unload) "gnus-start" "gnus-start.el"
;;;;;;  (15895 52376))
;;; Generated autoloads from gnus-start.el

(autoload (quote gnus-unload) "gnus-start" "\
Unload all Gnus features.
\(For some value of `all' or `Gnus'.)  Currently, features whose names
have prefixes `gnus-', `nn', `mm-' or `rfc' are unloaded.  Use
cautiously -- unloading may cause trouble." t nil)

(autoload (quote gnus-declare-backend) "gnus-start" "\
Declare backend NAME with ABILITIES as a Gnus backend." nil nil)

(autoload (quote gnus-fixup-nnimap-unread-after-getting-new-news) "gnus-start" nil nil nil)

;;;***

;;;### (autoloads (gnus-add-configuration) "gnus-win" "gnus-win.el"
;;;;;;  (15895 52379))
;;; Generated autoloads from gnus-win.el

(autoload (quote gnus-add-configuration) "gnus-win" "\
Add the window configuration CONF to `gnus-buffer-configuration'." nil nil)

;;;***

;;;### (autoloads (html2text) "html2text" "html2text.el" (15575 16896))
;;; Generated autoloads from html2text.el

(autoload (quote html2text) "html2text" "\
Convert HTML to plain text in the current buffer." t nil)

;;;***

;;;### (autoloads (unbold-region bold-region message-news-other-frame
;;;;;;  message-news-other-window message-mail-other-frame message-mail-other-window
;;;;;;  message-bounce message-resend message-insinuate-rmail message-forward-rmail-make-body
;;;;;;  message-forward-make-body message-forward message-recover
;;;;;;  message-supersede message-cancel-news message-followup message-wide-reply
;;;;;;  message-reply message-news message-mail message-mode message-reduce-to-to-cc
;;;;;;  message-cross-post-followup-to message-cross-post-insert-note
;;;;;;  message-cross-post-followup-to-header message-add-archive-header
;;;;;;  message-mark-insert-file message-mark-inserted-region message-change-subject
;;;;;;  message-signature-insert-empty-line message-signature-file
;;;;;;  message-signature message-indent-citation-function message-suspend-font-lock-when-citing
;;;;;;  message-cite-function message-yank-prefix message-citation-line-function
;;;;;;  message-send-mail-function message-user-organization-file
;;;;;;  message-signature-separator message-from-style message-cross-post-note-function
;;;;;;  message-followup-to-note message-cross-post-note message-cross-post-default
;;;;;;  message-archive-note message-archive-header message-mark-insert-end
;;;;;;  message-mark-insert-begin) "message" "message.el" (15895
;;;;;;  52380))
;;; Generated autoloads from message.el

(defvar message-mark-insert-begin "--8<---------------cut here---------------start------------->8---\n" "\
How to mark the beginning of some inserted text.")

(defvar message-mark-insert-end "--8<---------------cut here---------------end--------------->8---\n" "\
How to mark the end of some inserted text.")

(defvar message-archive-header "X-No-Archive: Yes\n" "\
Header to insert when you don't want your article to be archived.
Archives (such as groups.googgle.com) respect this header.")

(defvar message-archive-note "X-No-Archive: Yes - save http://groups.google.com/" "\
Note to insert why you wouldn't want this posting archived.
If nil, don't insert any text in the body.")

(defvar message-cross-post-default t "\
When non-nil `message-cross-post-followup-to' will normally perform a
crosspost.  If nil, `message-cross-post-followup-to' will only do a followup.
Note that you can explicitly override this setting by calling
`message-cross-post-followup-to' with a prefix.")

(defvar message-cross-post-note "Crosspost & Followup-To: " "\
Note to insert before signature to notify of xpost and follow-up.")

(defvar message-followup-to-note "Followup-To: " "\
Note to insert before signature to notify of follow-up only.")

(defvar message-cross-post-note-function (quote message-cross-post-insert-note) "\
Function to use to insert note about Crosspost or Followup-To.
The function will be called with four arguments.  The function should not only
insert a note, but also ensure old notes are deleted.  See the documentation
for `message-cross-post-insert-note'. ")

(defvar message-from-style (quote default) "\
*Specifies how \"From\" headers look.

If nil, they contain just the return address like:
	king@grassland.com
If `parens', they look like:
	king@grassland.com (Elvis Parsley)
If `angles', they look like:
	Elvis Parsley <king@grassland.com>

Otherwise, most addresses look like `angles', but they look like
`parens' if `angles' would need quoting and `parens' would not.")

(defvar message-signature-separator "^-- *$" "\
Regexp matching the signature separator.")

(defvar message-user-organization-file "/usr/lib/news/organization" "\
*Local news organization file.")

(defvar message-send-mail-function (quote message-send-mail-with-sendmail) "\
Function to call to send the current buffer as mail.
The headers should be delimited by a line whose contents match the
variable `mail-header-separator'.

Valid values include `message-send-mail-with-sendmail' (the default),
`message-send-mail-with-mh', `message-send-mail-with-qmail',
`message-send-mail-with-smtp', `message-smtpmail-send-it',
`smtpmail-send-it' and `feedmail-send-it'.

See also `send-mail-function'.")

(defvar message-citation-line-function (quote message-insert-citation-line) "\
*Function called to insert the \"Whomever writes:\" line.

Note that Gnus provides a feature where the reader can click on
`writes:' to hide the cited text.  If you change this line too much,
people who read your message will have to change their Gnus
configuration.  See the variable `gnus-cite-attribution-suffix'.")

(defvar message-yank-prefix "> " "\
*Prefix inserted on the lines of yanked messages.
Fix `message-cite-prefix-regexp' if it is set to an abnormal value.
See also `message-yank-cited-prefix'.")

(defvar message-cite-function (quote message-cite-original) "\
*Function for citing an original message.
Predefined functions include `message-cite-original' and
`message-cite-original-without-signature'.
Note that `message-cite-original' uses `mail-citation-hook' if that is non-nil.")

(defvar message-suspend-font-lock-when-citing nil "\
Non-nil means suspend font-lock'ing while citing an original message.
Some lazy demand-driven fontification tools (or Emacs itself) have a
bug that they often miss a buffer to be fontified.  It will mostly
occur when Emacs prompts user for any inputs in the minibuffer.
Setting this option to non-nil may help you to avoid unpleasant errors
even if it is an add-hoc expedient.")

(defvar message-indent-citation-function (quote message-indent-citation) "\
*Function for modifying a citation just inserted in the mail buffer.
This can also be a list of functions.  Each function can find the
citation between (point) and (mark t).  And each function should leave
point and mark around the citation text as modified.")

(defvar message-signature t "\
*String to be inserted at the end of the message buffer.
If t, the `message-signature-file' file will be inserted instead.
If a function, the result from the function will be used instead.
If a form, the result from the form will be used instead.")

(defvar message-signature-file "~/.signature" "\
*Name of file containing the text inserted at end of message buffer.
Ignored if the named file doesn't exist.
If nil, don't insert a signature.")

(defvar message-signature-insert-empty-line t "\
*If non-nil, insert an empty line before the signature separator.")

(define-mail-user-agent (quote message-user-agent) (quote message-mail) (quote message-send-and-exit) (quote message-kill-buffer) (quote message-send-hook))

(autoload (quote message-change-subject) "message" "\
Ask for new Subject: header, append (was: <Old Subject>)." t nil)

(autoload (quote message-mark-inserted-region) "message" "\
Mark some region in the current article with enclosing tags.
See `message-mark-insert-begin' and `message-mark-insert-end'." t nil)

(autoload (quote message-mark-insert-file) "message" "\
Inserts FILE at point, marking it with enclosing tags.
See `message-mark-insert-begin' and `message-mark-insert-end'." t nil)

(autoload (quote message-add-archive-header) "message" "\
Insert \"X-No-Archive: Yes\" in the header and a note in the body.
The note can be customized using `message-archive-note'.  When called with a
prefix argument, ask for a text to insert.  If you don't want the note in the
body, set  `message-archive-note' to nil." t nil)

(autoload (quote message-cross-post-followup-to-header) "message" "\
Mangles FollowUp-To and Newsgroups header to point to TARGET-GROUP.
With prefix-argument just set Follow-Up, don't cross-post." t nil)

(autoload (quote message-cross-post-insert-note) "message" "\
Insert a in message body note about a set Followup or Crosspost.
If there have been previous notes, delete them.  TARGET-GROUP specifies the
group to Followup-To.  When CROSS-POST is t, insert note about
crossposting.  IN-OLD specifies whether TARGET-GROUP is a member of
OLD-GROUPS.  OLD-GROUPS lists the old-groups the posting would have
been made to before the user asked for a Crosspost." nil nil)

(autoload (quote message-cross-post-followup-to) "message" "\
Crossposts message and sets Followup-To to TARGET-GROUP.
With prefix-argument just set Follow-Up, don't cross-post." t nil)

(autoload (quote message-reduce-to-to-cc) "message" "\
Replace contents of To: header with contents of Cc: or Bcc: header." t nil)

(autoload (quote message-mode) "message" "\
Major mode for editing mail and news to be sent.
Like Text Mode but with these additional commands:\\<message-mode-map>
C-c C-s  `message-send' (send the message)  C-c C-c  `message-send-and-exit'
C-c C-d  Postpone sending the message       C-c C-k  Kill the message
C-c C-f  move to a header field (and create it if there isn't):
	 C-c C-f C-t  move to To	C-c C-f C-s  move to Subject
	 C-c C-f C-c  move to Cc	C-c C-f C-b  move to Bcc
	 C-c C-f C-w  move to Fcc	C-c C-f C-r  move to Reply-To
	 C-c C-f C-u  move to Summary	C-c C-f C-n  move to Newsgroups
	 C-c C-f C-k  move to Keywords	C-c C-f C-d  move to Distribution
         C-c C-f C-o  move to From (\"Originator\")
	 C-c C-f C-f  move to Followup-To
	 C-c C-f C-m  move to Mail-Followup-To
	 C-c C-f c    move to Mail-Copies-To
	 C-c C-f C-i  cycle through Importance values
	 C-c C-f s    change subject and append \"(was: <Old Subject>)\"
	 C-c C-f x    crossposting with FollowUp-To header and note in body
	 C-c C-f t    replace To: header with contents of Cc: or Bcc:
	 C-c C-f a    Insert X-No-Archive: header and a note in the body
C-c C-t  `message-insert-to' (add a To header to a news followup)
C-c C-l  `message-to-list-only' (removes all but list address in to/cc)
C-c C-n  `message-insert-newsgroups' (add a Newsgroup header to a news reply)
C-c C-b  `message-goto-body' (move to beginning of message text).
C-c C-i  `message-goto-signature' (move to the beginning of the signature).
C-c C-w  `message-insert-signature' (insert `message-signature-file' file).
C-c C-y  `message-yank-original' (insert current message, if any).
C-c C-q  `message-fill-yanked-message' (fill what was yanked).
C-c C-e  `message-elide-region' (elide the text between point and mark).
C-c C-v  `message-delete-not-region' (remove the text outside the region).
C-c C-z  `message-kill-to-signature' (kill the text up to the signature).
C-c C-r  `message-caesar-buffer-body' (rot13 the message body).
C-c C-u  `message-insert-or-toggle-importance'  (insert or cycle importance).
C-c M-n  `message-insert-disposition-notification-to'  (request receipt).
C-c M-m  `message-mark-inserted-region' (mark region with enclosing tags).
C-c M-f  `message-mark-insert-file' (insert file marked with enclosing tags).
M-RET    `message-newline-and-reformat' (break the line and reformat)." t nil)

(autoload (quote message-mail) "message" "\
Start editing a mail message to be sent.
OTHER-HEADERS is an alist of header/value pairs." t nil)

(autoload (quote message-news) "message" "\
Start editing a news article to be sent." t nil)

(autoload (quote message-reply) "message" "\
Start editing a reply to the article in the current buffer." t nil)

(autoload (quote message-wide-reply) "message" "\
Make a \"wide\" reply to the message in the current buffer." t nil)

(autoload (quote message-followup) "message" "\
Follow up to the message in the current buffer.
If TO-NEWSGROUPS, use that as the new Newsgroups line." t nil)

(autoload (quote message-cancel-news) "message" "\
Cancel an article you posted.
If ARG, allow editing of the cancellation message." t nil)

(autoload (quote message-supersede) "message" "\
Start composing a message to supersede the current message.
This is done simply by taking the old article and adding a Supersedes
header line with the old Message-ID." t nil)

(autoload (quote message-recover) "message" "\
Reread contents of current buffer from its last auto-save file." t nil)

(autoload (quote message-forward) "message" "\
Forward the current message via mail.
Optional NEWS will use news to forward instead of mail." t nil)

(autoload (quote message-forward-make-body) "message" nil nil nil)

(autoload (quote message-forward-rmail-make-body) "message" nil nil nil)

(autoload (quote message-insinuate-rmail) "message" "\
Let RMAIL uses message to forward." t nil)

(autoload (quote message-resend) "message" "\
Resend the current article to ADDRESS." t nil)

(autoload (quote message-bounce) "message" "\
Re-mail the current message.
This only makes sense if the current message is a bounce message that
contains some mail you have written which has been bounced back to
you." t nil)

(autoload (quote message-mail-other-window) "message" "\
Like `message-mail' command, but display mail buffer in another window." t nil)

(autoload (quote message-mail-other-frame) "message" "\
Like `message-mail' command, but display mail buffer in another frame." t nil)

(autoload (quote message-news-other-window) "message" "\
Start editing a news article to be sent." t nil)

(autoload (quote message-news-other-frame) "message" "\
Start editing a news article to be sent." t nil)

(autoload (quote bold-region) "message" "\
Bold all nonblank characters in the region.
Works by overstriking characters.
Called from program, takes two arguments START and END
which specify the range to operate on." t nil)

(autoload (quote unbold-region) "message" "\
Remove all boldness (overstruck characters) in the region.
Called from program, takes two arguments START and END
which specify the range to operate on." t nil)

;;;***

;;;### (autoloads (mm-inline-external-body) "mm-extern" "mm-extern.el"
;;;;;;  (15418 33147))
;;; Generated autoloads from mm-extern.el

(autoload (quote mm-inline-external-body) "mm-extern" "\
Show the external-body part of HANDLE.
This function replaces the buffer of HANDLE with a buffer contains
the entire message.
If NO-DISPLAY is nil, display it. Otherwise, do nothing after replacing." nil nil)

;;;***

;;;### (autoloads (mm-inline-partial) "mm-partial" "mm-partial.el"
;;;;;;  (15575 16898))
;;; Generated autoloads from mm-partial.el

(autoload (quote mm-inline-partial) "mm-partial" "\
Show the partial part of HANDLE.
This function replaces the buffer of HANDLE with a buffer contains
the entire message.
If NO-DISPLAY is nil, display it. Otherwise, do nothing after replacing." nil nil)

;;;***

;;;### (autoloads (mm-uu-dissect) "mm-uu" "mm-uu.el" (15895 52382))
;;; Generated autoloads from mm-uu.el

(autoload (quote mm-uu-dissect) "mm-uu" "\
Dissect the current buffer and return a list of uu handles." nil nil)

;;;***

;;;### (autoloads (mml1991-sign mml1991-encrypt) "mml1991" "mml1991.el"
;;;;;;  (15895 52383))
;;; Generated autoloads from mml1991.el

(autoload (quote mml1991-encrypt) "mml1991" nil nil nil)

(autoload (quote mml1991-sign) "mml1991" nil nil nil)

;;;***

;;;### (autoloads (mml2015-self-encrypt mml2015-sign mml2015-encrypt
;;;;;;  mml2015-verify-test mml2015-verify mml2015-decrypt-test mml2015-decrypt)
;;;;;;  "mml2015" "mml2015.el" (15895 52383))
;;; Generated autoloads from mml2015.el

(autoload (quote mml2015-decrypt) "mml2015" nil nil nil)

(autoload (quote mml2015-decrypt-test) "mml2015" nil nil nil)

(autoload (quote mml2015-verify) "mml2015" nil nil nil)

(autoload (quote mml2015-verify-test) "mml2015" nil nil nil)

(autoload (quote mml2015-encrypt) "mml2015" nil nil nil)

(autoload (quote mml2015-sign) "mml2015" nil nil nil)

(autoload (quote mml2015-self-encrypt) "mml2015" nil nil nil)

;;;***

;;;### (autoloads (nndiary-generate-nov-databases) "nndiary" "nndiary.el"
;;;;;;  (15895 52383))
;;; Generated autoloads from nndiary.el

(autoload (quote nndiary-generate-nov-databases) "nndiary" "\
Generate NOV databases in all nndiary directories." t nil)

;;;***

;;;### (autoloads (nndoc-add-type) "nndoc" "nndoc.el" (15695 54015))
;;; Generated autoloads from nndoc.el

(autoload (quote nndoc-add-type) "nndoc" "\
Add document DEFINITION to the list of nndoc document definitions.
If POSITION is nil or `last', the definition will be added
as the last checked definition, if t or `first', add as the
first definition, and if any other symbol, add after that
symbol in the alist." nil nil)

;;;***

;;;### (autoloads (nnfolder-generate-active-file) "nnfolder" "nnfolder.el"
;;;;;;  (15895 52383))
;;; Generated autoloads from nnfolder.el

(autoload (quote nnfolder-generate-active-file) "nnfolder" "\
Look for mbox folders in the nnfolder directory and make them into groups.
This command does not work if you use short group names." t nil)

;;;***

;;;### (autoloads (nnkiboze-generate-groups) "nnkiboze" "nnkiboze.el"
;;;;;;  (15575 16905))
;;; Generated autoloads from nnkiboze.el

(autoload (quote nnkiboze-generate-groups) "nnkiboze" "\
\"Usage: emacs -batch -l nnkiboze -f nnkiboze-generate-groups\".
Finds out what articles are to be part of the nnkiboze groups." t nil)

;;;***

;;;### (autoloads (nnml-generate-nov-databases) "nnml" "nnml.el"
;;;;;;  (15895 52391))
;;; Generated autoloads from nnml.el

(autoload (quote nnml-generate-nov-databases) "nnml" "\
Generate NOV databases in all nnml directories." t nil)

;;;***

;;;### (autoloads (gnus-group-make-shimbun-group) "nnshimbun" "nnshimbun.el"
;;;;;;  (15895 52391))
;;; Generated autoloads from nnshimbun.el

(autoload (quote gnus-group-make-shimbun-group) "nnshimbun" "\
Create a nnshimbun group." t nil)

;;;***

;;;### (autoloads (nnsoup-revert-variables nnsoup-set-variables nnsoup-pack-replies)
;;;;;;  "nnsoup" "nnsoup.el" (15895 52391))
;;; Generated autoloads from nnsoup.el

(autoload (quote nnsoup-pack-replies) "nnsoup" "\
Make an outbound package of SOUP replies." t nil)

(autoload (quote nnsoup-set-variables) "nnsoup" "\
Use the SOUP methods for posting news and mailing mail." t nil)

(autoload (quote nnsoup-revert-variables) "nnsoup" "\
Revert posting and mailing methods to the standard Emacs methods." t nil)

;;;***

;;;### (autoloads (gnus-score-mode) "score-mode" "score-mode.el"
;;;;;;  (15418 33156))
;;; Generated autoloads from score-mode.el

(autoload (quote gnus-score-mode) "score-mode" "\
Mode for editing Gnus score files.
This mode is an extended emacs-lisp mode.

\\{gnus-score-mode-map}" t nil)

;;;***

;;;### (autoloads (sieve-upload sieve-manage) "sieve" "sieve.el"
;;;;;;  (15695 54016))
;;; Generated autoloads from sieve.el

(autoload (quote sieve-manage) "sieve" nil t nil)

(autoload (quote sieve-upload) "sieve" nil t nil)

;;;***

;;;### (autoloads (sieve-mode) "sieve-mode" "sieve-mode.el" (15695
;;;;;;  54016))
;;; Generated autoloads from sieve-mode.el

(autoload (quote sieve-mode) "sieve-mode" "\
Major mode for editing Sieve code.
This is much like C mode except for the syntax of comments.  Its keymap
inherits from C mode's and it has the same variables for customizing
indentation.  It has its own abbrev table and its own syntax table.

Turning on Sieve mode runs `sieve-mode-hook'." t nil)

;;;***

;;;### (autoloads (smiley-region) "smiley" "smiley.el" (15575 16907))
;;; Generated autoloads from smiley.el



;;;***

;;;### (autoloads (safe-date-to-time time-to-days time-to-day-in-year
;;;;;;  date-leap-year-p days-between date-to-day time-add time-subtract
;;;;;;  time-since days-to-time time-less-p seconds-to-time date-to-time)
;;;;;;  "time-date" "time-date.el" (15895 52392))
;;; Generated autoloads from time-date.el

(autoload (quote date-to-time) "time-date" "\
Parse a string that represents a date-time and return a time value." nil nil)

(autoload (quote seconds-to-time) "time-date" "\
Convert SECONDS (a floating point number) to a time value." nil nil)

(autoload (quote time-less-p) "time-date" "\
Say whether time value T1 is less than time value T2." nil nil)

(autoload (quote days-to-time) "time-date" "\
Convert DAYS into a time value." nil nil)

(autoload (quote time-since) "time-date" "\
Return the time elapsed since TIME.
TIME should be either a time value or a date-time string." nil nil)

(defalias (quote subtract-time) (quote time-subtract))

(autoload (quote time-subtract) "time-date" "\
Subtract two time values.
Return the difference in the format of a time value." nil nil)

(autoload (quote time-add) "time-date" "\
Add two time values.  One should represent a time difference." nil nil)

(autoload (quote date-to-day) "time-date" "\
Return the number of days between year 1 and DATE.
DATE should be a date-time string." nil nil)

(autoload (quote days-between) "time-date" "\
Return the number of days between DATE1 and DATE2.
DATE1 and DATE2 should be date-time strings." nil nil)

(autoload (quote date-leap-year-p) "time-date" "\
Return t if YEAR is a leap year." nil nil)

(autoload (quote time-to-day-in-year) "time-date" "\
Return the day number within the year of the date month/day/year." nil nil)

(autoload (quote time-to-days) "time-date" "\
The number of days between the Gregorian date 0001-12-31bce and TIME.
TIME should be a time value.
The Gregorian date Sunday, December 31, 1bce is imaginary." nil nil)

(autoload (quote safe-date-to-time) "time-date" "\
Parse a string that represents a date-time and return a time value.
If DATE is malformed, return a time value of zeros." nil nil)

;;;***

;;;### (autoloads (uudecode-decode-region uudecode-decode-region-internal
;;;;;;  uudecode-decode-region-external) "uudecode" "uudecode.el"
;;;;;;  (15418 33156))
;;; Generated autoloads from uudecode.el

(autoload (quote uudecode-decode-region-external) "uudecode" "\
Uudecode region between START and END using external program.
If FILE-NAME is non-nil, save the result to FILE-NAME.  The program
used is specified by `uudecode-decoder-program'." t nil)

(autoload (quote uudecode-decode-region-internal) "uudecode" "\
Uudecode region between START and END without using an external program.
If FILE-NAME is non-nil, save the result to FILE-NAME." t nil)

(autoload (quote uudecode-decode-region) "uudecode" "\
Uudecode region between START and END.
If FILE-NAME is non-nil, save the result to FILE-NAME." nil nil)

;;;***

;;;### (autoloads (yenc-extract-filename yenc-decode-region) "yenc"
;;;;;;  "yenc.el" (15895 52392))
;;; Generated autoloads from yenc.el

(autoload (quote yenc-decode-region) "yenc" "\
Yenc decode region between START and END using an internal decoder." t nil)

(autoload (quote yenc-extract-filename) "yenc" "\
Extract file name from an yenc header." nil nil)

;;;***

(provide 'gnus-load)

;;; Local Variables:
;;; version-control: never
;;; no-byte-compile: t
;;; no-update-autoloads: t
;;; End:
;;; gnus-load.el ends here
